@@ -38,7 +38,7 @@ job.month.also.during('OCT', 'DEC')
 job.every(2).days()
 job.setall(1, 12, None, None, None)
 
-job2 = cron.new(command='/foo/bar',comment='SomeID')
+job2 = cron.new(command='/foo/bar', comment='SomeID')
 job2.every_reboot()
 
 jobs = list(cron.find_command('bar'))
@@ -97,7 +97,7 @@ import subprocess as sp
 from datetime import date, datetime
 
 __pkgname__ = 'python-crontab'
-__version__ = '1.8'
+__version__ = '1.8.1'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -135,8 +135,10 @@ WINOS = platform.system() == 'Windows'
 SYSTEMV = not WINOS and os.uname()[0] in ["SunOS", "AIX", "HP-UX"]
 SYSTEMV = SYSTEMV or os.getenv('SYSTEMV_TEST')
 
+TESTING = False
 CRONCMD = "/usr/bin/crontab"
 if sys.argv[0].startswith('test_'):
+    TESTING = True
     CRONCMD = './data/crontest'
 
 try:
@@ -283,9 +285,9 @@ class CronTab(object):
         crons = []
         for cron in self.lines:
             crons.append(unicode(cron))
-        result = '\n'.join(crons)
-        if result and result[-1] not in ('\n', '\r'):
-            result += '\n'
+        result = u'\n'.join(crons)
+        if result and result[-1] not in (u'\n', u'\r'):
+            result += u'\n'
         return result
 
     def new(self, command='', comment=''):
@@ -386,7 +388,6 @@ class CronItem(object):
     def __init__(self, line=None, command='', comment='', cron=None):
         self.cron = cron
         self.valid = False
-        self.slices = []
         self.enabled = True
         self.special = False
         self.comment = comment
@@ -415,6 +416,10 @@ class CronItem(object):
         """Set the command and filter as needed"""
         self.command = cmd.strip()
 
+    def set_comment(self, cmt):
+        """Set the comment and don't filter"""
+        self.comment = cmt
+
     def parse(self, line):
         """Parse a cron line string and save the info as the objects."""
         if type(line) is str and not PY3:
@@ -450,11 +455,15 @@ class CronItem(object):
 
     def render(self):
         """Render this set cron-job to a string"""
-        result = "%s %s" % (str(self.slices), self.command)
+        if type(self.command) is str and not PY3:
+            self.command = unicode(self.command, 'utf-8')
+        result = u"%s %s" % (str(self.slices), self.command)
         if self.comment:
-            result += " # " + self.comment
+            if type(self.comment) is str and not PY3:
+                self.comment = unicode(self.comment, 'utf-8')
+            result += u" # " + self.comment
         if not self.enabled:
-            result = "# " + result
+            result = u"# " + result
         return result
 
     def every_reboot(self):
@@ -663,6 +672,10 @@ class CronSlices(list):
         for a, b in zip(self, slices):
             try:
                 a.parse(b)
+            except ValueError as error:
+                if not TESTING:
+                    sys.stderr.write("WARNING: %s\n" % str(error))
+                return False
             except Exception:
                 return False
         return True
@@ -718,6 +731,10 @@ class CronSlices(list):
         return self.render() == CronSlices(arg).render()
 
 
+class SundayError(KeyError):
+    pass
+
+
 class CronSlice(object):
     """Cron slice object which shows a time pattern"""
     def __init__(self, info, value=None):
@@ -740,9 +757,10 @@ class CronSlice(object):
             else:
                 try:
                     self.parts.append(self._v(part))
-                except ValueError:
-                    raise ValueError('Unknown cron time part for %s: %s' % (
-                        self.name, part))
+                except SundayError:
+                    self.parts.append(0)
+                except ValueError as err:
+                    raise ValueError('%s:%s/%s' % (str(err), self.name, part))
 
     def render(self, resolve=False):
         """Return the slice rendered as a crontab.
@@ -778,7 +796,10 @@ class CronSlice(object):
         if not opts.get('also', False):
             self.clear()
         for av in n_value:
-            self.parts += self._v(av),
+            try:
+                self.parts += self._v(av),
+            except SundayError:
+                self.parts += 0,
         return self.parts
 
     def during(self, vfrom, vto, also=False):
@@ -847,9 +868,8 @@ class CronSlice(object):
         except KeyError:
             raise KeyError("No enumeration '%s' got '%s'" % (self.name, v))
 
-        # If it's a sunday, make it a sunday (force 7 to 0)
-        if self.max == 6 and v == 7:
-            out = 0
+        if self.max == 6 and int(out) == 7:
+            raise SundayError("Detected Sunday as 7 instead of 0!")
 
         if int(out) < self.min or int(out) > self.max:
             raise ValueError("Invalid value '%s', expected %d-%d for %s" % (
@@ -929,11 +949,16 @@ class CronRange(object):
         """Parse a ranged value in a cronjob"""
         if value.count('/') == 1:
             value, seq = value.split('/')
-            self.seq = int(seq)
+            self.seq = self.slice.filter_v(seq)
+            if self.seq < 1 or self.seq > self.slice.max - 1:
+                raise ValueError("Sequence can not be divided by zero or max")
         if value.count('-') == 1:
             vfrom, vto = value.split('-')
             self.vfrom = self.slice.filter_v(vfrom)
-            self.vto = self.slice.filter_v(vto)
+            try:
+                self.vto = self.slice.filter_v(vto)
+            except SundayError:
+                self.vto = 6
         elif value == '*':
             self.all()
         else:
