@@ -66,12 +66,12 @@ class BasicTestCase(unittest.TestCase):
         results = RESULT_TAB.split('\n')
         line_no = 0
         for line in self.crontab.intab.split('\n'):
-            self.assertEqual(line, results[line_no])
+            self.assertEqual(str(line), results[line_no])
             line_no += 1
 
     def test_02_simple_enum(self):
         """Simple Enumerations"""
-        e = self.crontab.find_command('enums')[0]
+        e = list(self.crontab.find_command('enums'))[0]
         self.assertEqual(e.month, 'JAN')
         self.assertEqual(e.month.render(True), '1')
         self.assertEqual(e.dow, 'SAT')
@@ -79,13 +79,13 @@ class BasicTestCase(unittest.TestCase):
 
     def test_03_enum_range(self):
         """Enumeration Ranges"""
-        e = self.crontab.find_command('ranges')[0]
+        e = list(self.crontab.find_command('ranges'))[0]
         self.assertEqual(e.month, 'MAR-APR')
         self.assertEqual(e.month.render(True), '3-4' )
 
     def test_04_sets(self):
         """Enumeration Sets"""
-        e = self.crontab.find_command('multiples')[0]
+        e = list(self.crontab.find_command('multiples'))[0]
         self.assertEqual(e.dow, 'MON,WED,FRI')
         self.assertEqual(e.dow.render(True), '1,3,5' )
 
@@ -94,24 +94,24 @@ class BasicTestCase(unittest.TestCase):
         job = self.crontab.new(command='new')
         job.month.on('JAN')
         job.dow.on('SUN')
-        self.assertEqual(job, '* * * JAN SUN new')
+        self.assertEqual(str(job), '* * * JAN SUN new')
 
     def test_06_create_range(self):
         """Created Enum Range"""
         job = self.crontab.new(command='new2')
         job.month.during('APR', 'NOV').every(2)
-        self.assertEqual(job, '* * * APR-NOV/2 * new2')
+        self.assertEqual(str(job), '* * * APR-NOV/2 * new2')
 
     def test_07_create_set(self):
         """Created Enum Set"""
         job = self.crontab.new(command='new3')
         job.month.on('APR')
         job.month.also.on('NOV','JAN')
-        self.assertEqual(job, '* * * JAN,APR,NOV * new3')
+        self.assertEqual(str(job), '* * * JAN,APR,NOV * new3')
 
     def test_08_find_comment(self):
         """Comment Set"""
-        jobs = self.crontab.find_comment('Comment One')
+        jobs = list(self.crontab.find_comment('Comment One'))
         self.assertEqual(len(jobs), 2)
         for job in jobs:
             self.assertEqual(job.comment, 'Comment One')
